# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from prodvana.proto.prodvana.release_channel import release_channel_manager_pb2 as prodvana_dot_release__channel_dot_release__channel__manager__pb2


class ReleaseChannelManagerStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ConfigureReleaseChannel = channel.unary_unary(
                '/prodvana.release_channel.ReleaseChannelManager/ConfigureReleaseChannel',
                request_serializer=prodvana_dot_release__channel_dot_release__channel__manager__pb2.ConfigureReleaseChannelReq.SerializeToString,
                response_deserializer=prodvana_dot_release__channel_dot_release__channel__manager__pb2.ConfigureReleaseChannelResp.FromString,
                )
        self.ListReleaseChannels = channel.unary_unary(
                '/prodvana.release_channel.ReleaseChannelManager/ListReleaseChannels',
                request_serializer=prodvana_dot_release__channel_dot_release__channel__manager__pb2.ListReleaseChannelsReq.SerializeToString,
                response_deserializer=prodvana_dot_release__channel_dot_release__channel__manager__pb2.ListReleaseChannelsResp.FromString,
                )
        self.DeleteReleaseChannel = channel.unary_unary(
                '/prodvana.release_channel.ReleaseChannelManager/DeleteReleaseChannel',
                request_serializer=prodvana_dot_release__channel_dot_release__channel__manager__pb2.DeleteReleaseChannelReq.SerializeToString,
                response_deserializer=prodvana_dot_release__channel_dot_release__channel__manager__pb2.DeleteReleaseChannelResp.FromString,
                )
        self.ListReleaseChannelsV2 = channel.unary_unary(
                '/prodvana.release_channel.ReleaseChannelManager/ListReleaseChannelsV2',
                request_serializer=prodvana_dot_release__channel_dot_release__channel__manager__pb2.ListReleaseChannelsReq.SerializeToString,
                response_deserializer=prodvana_dot_release__channel_dot_release__channel__manager__pb2.ListReleaseChannelsResp.FromString,
                )
        self.GetReleaseChannel = channel.unary_unary(
                '/prodvana.release_channel.ReleaseChannelManager/GetReleaseChannel',
                request_serializer=prodvana_dot_release__channel_dot_release__channel__manager__pb2.GetReleaseChannelReq.SerializeToString,
                response_deserializer=prodvana_dot_release__channel_dot_release__channel__manager__pb2.GetReleaseChannelResp.FromString,
                )
        self.GetReleaseChannelConfig = channel.unary_unary(
                '/prodvana.release_channel.ReleaseChannelManager/GetReleaseChannelConfig',
                request_serializer=prodvana_dot_release__channel_dot_release__channel__manager__pb2.GetReleaseChannelConfigReq.SerializeToString,
                response_deserializer=prodvana_dot_release__channel_dot_release__channel__manager__pb2.GetReleaseChannelConfigResp.FromString,
                )
        self.GetReleaseChannelEvents = channel.unary_unary(
                '/prodvana.release_channel.ReleaseChannelManager/GetReleaseChannelEvents',
                request_serializer=prodvana_dot_release__channel_dot_release__channel__manager__pb2.GetReleaseChannelEventsReq.SerializeToString,
                response_deserializer=prodvana_dot_release__channel_dot_release__channel__manager__pb2.GetReleaseChannelEventsResp.FromString,
                )


class ReleaseChannelManagerServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ConfigureReleaseChannel(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListReleaseChannels(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteReleaseChannel(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListReleaseChannelsV2(self, request, context):
        """identical to ListReleaseChannels, kept for backwards compatibility
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetReleaseChannel(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetReleaseChannelConfig(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetReleaseChannelEvents(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ReleaseChannelManagerServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ConfigureReleaseChannel': grpc.unary_unary_rpc_method_handler(
                    servicer.ConfigureReleaseChannel,
                    request_deserializer=prodvana_dot_release__channel_dot_release__channel__manager__pb2.ConfigureReleaseChannelReq.FromString,
                    response_serializer=prodvana_dot_release__channel_dot_release__channel__manager__pb2.ConfigureReleaseChannelResp.SerializeToString,
            ),
            'ListReleaseChannels': grpc.unary_unary_rpc_method_handler(
                    servicer.ListReleaseChannels,
                    request_deserializer=prodvana_dot_release__channel_dot_release__channel__manager__pb2.ListReleaseChannelsReq.FromString,
                    response_serializer=prodvana_dot_release__channel_dot_release__channel__manager__pb2.ListReleaseChannelsResp.SerializeToString,
            ),
            'DeleteReleaseChannel': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteReleaseChannel,
                    request_deserializer=prodvana_dot_release__channel_dot_release__channel__manager__pb2.DeleteReleaseChannelReq.FromString,
                    response_serializer=prodvana_dot_release__channel_dot_release__channel__manager__pb2.DeleteReleaseChannelResp.SerializeToString,
            ),
            'ListReleaseChannelsV2': grpc.unary_unary_rpc_method_handler(
                    servicer.ListReleaseChannelsV2,
                    request_deserializer=prodvana_dot_release__channel_dot_release__channel__manager__pb2.ListReleaseChannelsReq.FromString,
                    response_serializer=prodvana_dot_release__channel_dot_release__channel__manager__pb2.ListReleaseChannelsResp.SerializeToString,
            ),
            'GetReleaseChannel': grpc.unary_unary_rpc_method_handler(
                    servicer.GetReleaseChannel,
                    request_deserializer=prodvana_dot_release__channel_dot_release__channel__manager__pb2.GetReleaseChannelReq.FromString,
                    response_serializer=prodvana_dot_release__channel_dot_release__channel__manager__pb2.GetReleaseChannelResp.SerializeToString,
            ),
            'GetReleaseChannelConfig': grpc.unary_unary_rpc_method_handler(
                    servicer.GetReleaseChannelConfig,
                    request_deserializer=prodvana_dot_release__channel_dot_release__channel__manager__pb2.GetReleaseChannelConfigReq.FromString,
                    response_serializer=prodvana_dot_release__channel_dot_release__channel__manager__pb2.GetReleaseChannelConfigResp.SerializeToString,
            ),
            'GetReleaseChannelEvents': grpc.unary_unary_rpc_method_handler(
                    servicer.GetReleaseChannelEvents,
                    request_deserializer=prodvana_dot_release__channel_dot_release__channel__manager__pb2.GetReleaseChannelEventsReq.FromString,
                    response_serializer=prodvana_dot_release__channel_dot_release__channel__manager__pb2.GetReleaseChannelEventsResp.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'prodvana.release_channel.ReleaseChannelManager', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class ReleaseChannelManager(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ConfigureReleaseChannel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.release_channel.ReleaseChannelManager/ConfigureReleaseChannel',
            prodvana_dot_release__channel_dot_release__channel__manager__pb2.ConfigureReleaseChannelReq.SerializeToString,
            prodvana_dot_release__channel_dot_release__channel__manager__pb2.ConfigureReleaseChannelResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListReleaseChannels(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.release_channel.ReleaseChannelManager/ListReleaseChannels',
            prodvana_dot_release__channel_dot_release__channel__manager__pb2.ListReleaseChannelsReq.SerializeToString,
            prodvana_dot_release__channel_dot_release__channel__manager__pb2.ListReleaseChannelsResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteReleaseChannel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.release_channel.ReleaseChannelManager/DeleteReleaseChannel',
            prodvana_dot_release__channel_dot_release__channel__manager__pb2.DeleteReleaseChannelReq.SerializeToString,
            prodvana_dot_release__channel_dot_release__channel__manager__pb2.DeleteReleaseChannelResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListReleaseChannelsV2(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.release_channel.ReleaseChannelManager/ListReleaseChannelsV2',
            prodvana_dot_release__channel_dot_release__channel__manager__pb2.ListReleaseChannelsReq.SerializeToString,
            prodvana_dot_release__channel_dot_release__channel__manager__pb2.ListReleaseChannelsResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetReleaseChannel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.release_channel.ReleaseChannelManager/GetReleaseChannel',
            prodvana_dot_release__channel_dot_release__channel__manager__pb2.GetReleaseChannelReq.SerializeToString,
            prodvana_dot_release__channel_dot_release__channel__manager__pb2.GetReleaseChannelResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetReleaseChannelConfig(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.release_channel.ReleaseChannelManager/GetReleaseChannelConfig',
            prodvana_dot_release__channel_dot_release__channel__manager__pb2.GetReleaseChannelConfigReq.SerializeToString,
            prodvana_dot_release__channel_dot_release__channel__manager__pb2.GetReleaseChannelConfigResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetReleaseChannelEvents(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.release_channel.ReleaseChannelManager/GetReleaseChannelEvents',
            prodvana_dot_release__channel_dot_release__channel__manager__pb2.GetReleaseChannelEventsReq.SerializeToString,
            prodvana_dot_release__channel_dot_release__channel__manager__pb2.GetReleaseChannelEventsResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/protection/protection_manager.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from prodvana.proto.prodvana.protection import object_pb2 as prodvana_dot_protection_dot_object__pb2
from prodvana.proto.prodvana.protection import protection_config_pb2 as prodvana_dot_protection_dot_protection__config__pb2
from prodvana.proto.prodvana.version import source_metadata_pb2 as prodvana_dot_version_dot_source__metadata__pb2
from prodvana.proto.validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,prodvana/protection/protection_manager.proto\x12\x13prodvana.protection\x1a\x1cgoogle/api/annotations.proto\x1a prodvana/protection/object.proto\x1a+prodvana/protection/protection_config.proto\x1a&prodvana/version/source_metadata.proto\x1a\x17validate/validate.proto\"\xc9\x01\n\x16\x43onfigureProtectionReq\x12J\n\x11protection_config\x18\x01 \x01(\x0b\x32%.prodvana.protection.ProtectionConfigB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12(\n\x06source\x18\x02 \x01(\x0e\x32\x18.prodvana.version.Source\x12\x39\n\x0fsource_metadata\x18\x03 \x01(\x0b\x32 .prodvana.version.SourceMetadata\"A\n\x17\x43onfigureProtectionResp\x12\x15\n\rprotection_id\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\"\x9e\x01\n\x1fValidateConfigureProtectionResp\x12;\n\x0cinput_config\x18\x01 \x01(\x0b\x32%.prodvana.protection.ProtectionConfig\x12>\n\x0f\x63ompiled_config\x18\x02 \x01(\x0b\x32%.prodvana.protection.ProtectionConfig\";\n\x12ListProtectionsReq\x12\x12\n\npage_token\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\"d\n\x13ListProtectionsResp\x12\x34\n\x0bprotections\x18\x01 \x03(\x0b\x32\x1f.prodvana.protection.Protection\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"/\n\x10GetProtectionReq\x12\x1b\n\nprotection\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\"H\n\x11GetProtectionResp\x12\x33\n\nprotection\x18\x01 \x01(\x0b\x32\x1f.prodvana.protection.Protection\"F\n\x16GetProtectionConfigReq\x12\x1b\n\nprotection\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x0f\n\x07version\x18\x02 \x01(\t\"\xa7\x01\n\x17GetProtectionConfigResp\x12;\n\x0cinput_config\x18\x03 \x01(\x0b\x32%.prodvana.protection.ProtectionConfig\x12>\n\x0f\x63ompiled_config\x18\x01 \x01(\x0b\x32%.prodvana.protection.ProtectionConfig\x12\x0f\n\x07version\x18\x02 \x01(\t\"S\n GetProtectionAttachmentConfigReq\x12\x1e\n\rattachment_id\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x0f\n\x07version\x18\x02 \x01(\t\"}\n!GetProtectionAttachmentConfigResp\x12G\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x37.prodvana.protection.CompiledProtectionAttachmentConfig\x12\x0f\n\x07version\x18\x02 \x01(\t2\xd6\x07\n\x11ProtectionManager\x12\x96\x01\n\x13\x43onfigureProtection\x12+.prodvana.protection.ConfigureProtectionReq\x1a,.prodvana.protection.ConfigureProtectionResp\"$\x82\xd3\xe4\x93\x02\x1e\"\x19/v1/protections/configure:\x01*\x12\xaf\x01\n\x1bValidateConfigureProtection\x12+.prodvana.protection.ConfigureProtectionReq\x1a\x34.prodvana.protection.ValidateConfigureProtectionResp\"-\x82\xd3\xe4\x93\x02\'\"\"/v1/protections/configure/validate:\x01*\x12}\n\x0fListProtections\x12\'.prodvana.protection.ListProtectionsReq\x1a(.prodvana.protection.ListProtectionsResp\"\x17\x82\xd3\xe4\x93\x02\x11\x12\x0f/v1/protections\x12\x86\x01\n\rGetProtection\x12%.prodvana.protection.GetProtectionReq\x1a&.prodvana.protection.GetProtectionResp\"&\x82\xd3\xe4\x93\x02 \x12\x1e/v1/protections/{protection=*}\x12\x9f\x01\n\x13GetProtectionConfig\x12+.prodvana.protection.GetProtectionConfigReq\x1a,.prodvana.protection.GetProtectionConfigResp\"-\x82\xd3\xe4\x93\x02\'\x12%/v1/protections/{protection=*}/config\x12\xcb\x01\n\x1dGetProtectionAttachmentConfig\x12\x35.prodvana.protection.GetProtectionAttachmentConfigReq\x1a\x36.prodvana.protection.GetProtectionAttachmentConfigResp\";\x82\xd3\xe4\x93\x02\x35\x12\x33/v1/protections/attachment/{attachment_id=*}/configBOZMgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/protectionb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'prodvana.protection.protection_manager_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZMgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/protection'
  _CONFIGUREPROTECTIONREQ.fields_by_name['protection_config']._options = None
  _CONFIGUREPROTECTIONREQ.fields_by_name['protection_config']._serialized_options = b'\372B\005\212\001\002\020\001'
  _GETPROTECTIONREQ.fields_by_name['protection']._options = None
  _GETPROTECTIONREQ.fields_by_name['protection']._serialized_options = b'\372B\004r\002\020\001'
  _GETPROTECTIONCONFIGREQ.fields_by_name['protection']._options = None
  _GETPROTECTIONCONFIGREQ.fields_by_name['protection']._serialized_options = b'\372B\004r\002\020\001'
  _GETPROTECTIONATTACHMENTCONFIGREQ.fields_by_name['attachment_id']._options = None
  _GETPROTECTIONATTACHMENTCONFIGREQ.fields_by_name['attachment_id']._serialized_options = b'\372B\004r\002\020\001'
  _PROTECTIONMANAGER.methods_by_name['ConfigureProtection']._options = None
  _PROTECTIONMANAGER.methods_by_name['ConfigureProtection']._serialized_options = b'\202\323\344\223\002\036\"\031/v1/protections/configure:\001*'
  _PROTECTIONMANAGER.methods_by_name['ValidateConfigureProtection']._options = None
  _PROTECTIONMANAGER.methods_by_name['ValidateConfigureProtection']._serialized_options = b'\202\323\344\223\002\'\"\"/v1/protections/configure/validate:\001*'
  _PROTECTIONMANAGER.methods_by_name['ListProtections']._options = None
  _PROTECTIONMANAGER.methods_by_name['ListProtections']._serialized_options = b'\202\323\344\223\002\021\022\017/v1/protections'
  _PROTECTIONMANAGER.methods_by_name['GetProtection']._options = None
  _PROTECTIONMANAGER.methods_by_name['GetProtection']._serialized_options = b'\202\323\344\223\002 \022\036/v1/protections/{protection=*}'
  _PROTECTIONMANAGER.methods_by_name['GetProtectionConfig']._options = None
  _PROTECTIONMANAGER.methods_by_name['GetProtectionConfig']._serialized_options = b'\202\323\344\223\002\'\022%/v1/protections/{protection=*}/config'
  _PROTECTIONMANAGER.methods_by_name['GetProtectionAttachmentConfig']._options = None
  _PROTECTIONMANAGER.methods_by_name['GetProtectionAttachmentConfig']._serialized_options = b'\202\323\344\223\0025\0223/v1/protections/attachment/{attachment_id=*}/config'
  _globals['_CONFIGUREPROTECTIONREQ']._serialized_start=244
  _globals['_CONFIGUREPROTECTIONREQ']._serialized_end=445
  _globals['_CONFIGUREPROTECTIONRESP']._serialized_start=447
  _globals['_CONFIGUREPROTECTIONRESP']._serialized_end=512
  _globals['_VALIDATECONFIGUREPROTECTIONRESP']._serialized_start=515
  _globals['_VALIDATECONFIGUREPROTECTIONRESP']._serialized_end=673
  _globals['_LISTPROTECTIONSREQ']._serialized_start=675
  _globals['_LISTPROTECTIONSREQ']._serialized_end=734
  _globals['_LISTPROTECTIONSRESP']._serialized_start=736
  _globals['_LISTPROTECTIONSRESP']._serialized_end=836
  _globals['_GETPROTECTIONREQ']._serialized_start=838
  _globals['_GETPROTECTIONREQ']._serialized_end=885
  _globals['_GETPROTECTIONRESP']._serialized_start=887
  _globals['_GETPROTECTIONRESP']._serialized_end=959
  _globals['_GETPROTECTIONCONFIGREQ']._serialized_start=961
  _globals['_GETPROTECTIONCONFIGREQ']._serialized_end=1031
  _globals['_GETPROTECTIONCONFIGRESP']._serialized_start=1034
  _globals['_GETPROTECTIONCONFIGRESP']._serialized_end=1201
  _globals['_GETPROTECTIONATTACHMENTCONFIGREQ']._serialized_start=1203
  _globals['_GETPROTECTIONATTACHMENTCONFIGREQ']._serialized_end=1286
  _globals['_GETPROTECTIONATTACHMENTCONFIGRESP']._serialized_start=1288
  _globals['_GETPROTECTIONATTACHMENTCONFIGRESP']._serialized_end=1413
  _globals['_PROTECTIONMANAGER']._serialized_start=1416
  _globals['_PROTECTIONMANAGER']._serialized_end=2398
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/runtimes/extensions/get_info.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+prodvana/runtimes/extensions/get_info.proto\x12\x1cprodvana.runtimes.extensions\"M\n\rGetInfoOutput\x12<\n\x07outputs\x18\x01 \x03(\x0b\x32+.prodvana.runtimes.extensions.OutputContent\"+\n\rOutputContent\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04text\x18\x02 \x01(\tBXZVgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/runtimes/extensionsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'prodvana.runtimes.extensions.get_info_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZVgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/runtimes/extensions'
  _globals['_GETINFOOUTPUT']._serialized_start=77
  _globals['_GETINFOOUTPUT']._serialized_end=154
  _globals['_OUTPUTCONTENT']._serialized_start=156
  _globals['_OUTPUTCONTENT']._serialized_end=199
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import collections.abc
import grpc
import prodvana.proto.prodvana.agent.agent_interaction_pb2

class AgentInteractionStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    Heartbeat: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.agent.agent_interaction_pb2.HeartbeatReq,
        prodvana.proto.prodvana.agent.agent_interaction_pb2.HeartbeatResp,
    ]
    ConfirmPushApproval: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.agent.agent_interaction_pb2.ConfirmPushApprovalReq,
        prodvana.proto.prodvana.agent.agent_interaction_pb2.ConfirmPushApprovalResp,
    ]
    RecordNewUnknownPush: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.agent.agent_interaction_pb2.RecordNewUnknownPushReq,
        prodvana.proto.prodvana.agent.agent_interaction_pb2.RecordNewUnknownPushResp,
    ]
    RecordPushStart: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.agent.agent_interaction_pb2.RecordPushStartReq,
        prodvana.proto.prodvana.agent.agent_interaction_pb2.RecordPushStartResp,
    ]
    RecordPushOngoing: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.agent.agent_interaction_pb2.RecordPushOngoingReq,
        prodvana.proto.prodvana.agent.agent_interaction_pb2.RecordPushOngoingResp,
    ]
    RecordPushComplete: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.agent.agent_interaction_pb2.RecordPushCompleteReq,
        prodvana.proto.prodvana.agent.agent_interaction_pb2.RecordPushCompleteResp,
    ]
    RecordPod: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.agent.agent_interaction_pb2.RecordPodReq,
        prodvana.proto.prodvana.agent.agent_interaction_pb2.RecordPodResp,
    ]
    RecordPods: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.agent.agent_interaction_pb2.RecordPodsReq,
        prodvana.proto.prodvana.agent.agent_interaction_pb2.RecordPodsResp,
    ]
    """Dump a snapshot of all pods for a service. Can potentially contain multiple services, or all services.
    Guaranteed to contain all pods for one service.
    """
    RecordDeployment: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.agent.agent_interaction_pb2.RecordDeploymentReq,
        prodvana.proto.prodvana.agent.agent_interaction_pb2.RecordDeploymentResp,
    ]
    RecordRollout: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.agent.agent_interaction_pb2.RecordRolloutReq,
        prodvana.proto.prodvana.agent.agent_interaction_pb2.RecordRolloutResp,
    ]
    ProxyAPIServer: grpc.StreamStreamMultiCallable[
        prodvana.proto.prodvana.agent.agent_interaction_pb2.ProxyAPIServerReq,
        prodvana.proto.prodvana.agent.agent_interaction_pb2.ProxyAPIServerResp,
    ]
    ReportDebugInfo: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.agent.agent_interaction_pb2.ReportDebugInfoReq,
        prodvana.proto.prodvana.agent.agent_interaction_pb2.ReportDebugInfoResp,
    ]
    ReportClusterMetadata: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.agent.agent_interaction_pb2.ReportClusterMetadataReq,
        prodvana.proto.prodvana.agent.agent_interaction_pb2.ReportClusterMetadataResp,
    ]

class AgentInteractionServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def Heartbeat(
        self,
        request: prodvana.proto.prodvana.agent.agent_interaction_pb2.HeartbeatReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.agent.agent_interaction_pb2.HeartbeatResp: ...
    @abc.abstractmethod
    def ConfirmPushApproval(
        self,
        request: prodvana.proto.prodvana.agent.agent_interaction_pb2.ConfirmPushApprovalReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.agent.agent_interaction_pb2.ConfirmPushApprovalResp: ...
    @abc.abstractmethod
    def RecordNewUnknownPush(
        self,
        request: prodvana.proto.prodvana.agent.agent_interaction_pb2.RecordNewUnknownPushReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.agent.agent_interaction_pb2.RecordNewUnknownPushResp: ...
    @abc.abstractmethod
    def RecordPushStart(
        self,
        request: prodvana.proto.prodvana.agent.agent_interaction_pb2.RecordPushStartReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.agent.agent_interaction_pb2.RecordPushStartResp: ...
    @abc.abstractmethod
    def RecordPushOngoing(
        self,
        request: prodvana.proto.prodvana.agent.agent_interaction_pb2.RecordPushOngoingReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.agent.agent_interaction_pb2.RecordPushOngoingResp: ...
    @abc.abstractmethod
    def RecordPushComplete(
        self,
        request: prodvana.proto.prodvana.agent.agent_interaction_pb2.RecordPushCompleteReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.agent.agent_interaction_pb2.RecordPushCompleteResp: ...
    @abc.abstractmethod
    def RecordPod(
        self,
        request: prodvana.proto.prodvana.agent.agent_interaction_pb2.RecordPodReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.agent.agent_interaction_pb2.RecordPodResp: ...
    @abc.abstractmethod
    def RecordPods(
        self,
        request: prodvana.proto.prodvana.agent.agent_interaction_pb2.RecordPodsReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.agent.agent_interaction_pb2.RecordPodsResp:
        """Dump a snapshot of all pods for a service. Can potentially contain multiple services, or all services.
        Guaranteed to contain all pods for one service.
        """
    @abc.abstractmethod
    def RecordDeployment(
        self,
        request: prodvana.proto.prodvana.agent.agent_interaction_pb2.RecordDeploymentReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.agent.agent_interaction_pb2.RecordDeploymentResp: ...
    @abc.abstractmethod
    def RecordRollout(
        self,
        request: prodvana.proto.prodvana.agent.agent_interaction_pb2.RecordRolloutReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.agent.agent_interaction_pb2.RecordRolloutResp: ...
    @abc.abstractmethod
    def ProxyAPIServer(
        self,
        request_iterator: collections.abc.Iterator[prodvana.proto.prodvana.agent.agent_interaction_pb2.ProxyAPIServerReq],
        context: grpc.ServicerContext,
    ) -> collections.abc.Iterator[prodvana.proto.prodvana.agent.agent_interaction_pb2.ProxyAPIServerResp]: ...
    @abc.abstractmethod
    def ReportDebugInfo(
        self,
        request: prodvana.proto.prodvana.agent.agent_interaction_pb2.ReportDebugInfoReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.agent.agent_interaction_pb2.ReportDebugInfoResp: ...
    @abc.abstractmethod
    def ReportClusterMetadata(
        self,
        request: prodvana.proto.prodvana.agent.agent_interaction_pb2.ReportClusterMetadataReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.agent.agent_interaction_pb2.ReportClusterMetadataResp: ...

def add_AgentInteractionServicer_to_server(servicer: AgentInteractionServicer, server: grpc.Server) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import prodvana.proto.prodvana.common_config.env_pb2
import prodvana.proto.prodvana.common_config.kubernetes_config_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class RemoteHelmChart(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REPO_FIELD_NUMBER: builtins.int
    CHART_FIELD_NUMBER: builtins.int
    CHART_VERSION_FIELD_NUMBER: builtins.int
    repo: builtins.str
    """TODO(naphat) add integration support for private repositories"""
    chart: builtins.str
    chart_version: builtins.str
    def __init__(
        self,
        *,
        repo: builtins.str = ...,
        chart: builtins.str = ...,
        chart_version: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["repo", b"repo", "repo_oneof", b"repo_oneof"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["chart", b"chart", "chart_version", b"chart_version", "repo", b"repo", "repo_oneof", b"repo_oneof"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["repo_oneof", b"repo_oneof"]) -> typing_extensions.Literal["repo"] | None: ...

global___RemoteHelmChart = RemoteHelmChart

class HelmValuesOverrides(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class MapEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        @property
        def value(self) -> prodvana.proto.prodvana.common_config.env_pb2.EnvValue: ...
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: prodvana.proto.prodvana.common_config.env_pb2.EnvValue | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    INLINED_FIELD_NUMBER: builtins.int
    LOCAL_FIELD_NUMBER: builtins.int
    MAP_FIELD_NUMBER: builtins.int
    inlined: builtins.str
    @property
    def local(self) -> prodvana.proto.prodvana.common_config.kubernetes_config_pb2.LocalConfig: ...
    @property
    def map(self) -> google.protobuf.internal.containers.MessageMap[builtins.str, prodvana.proto.prodvana.common_config.env_pb2.EnvValue]:
        """treat this as part of the above oneof, even though proto does not allow us to"""
    def __init__(
        self,
        *,
        inlined: builtins.str = ...,
        local: prodvana.proto.prodvana.common_config.kubernetes_config_pb2.LocalConfig | None = ...,
        map: collections.abc.Mapping[builtins.str, prodvana.proto.prodvana.common_config.env_pb2.EnvValue] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["inlined", b"inlined", "local", b"local", "override_oneof", b"override_oneof"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["inlined", b"inlined", "local", b"local", "map", b"map", "override_oneof", b"override_oneof"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["override_oneof", b"override_oneof"]) -> typing_extensions.Literal["inlined", "local"] | None: ...

global___HelmValuesOverrides = HelmValuesOverrides

class HelmConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REMOTE_FIELD_NUMBER: builtins.int
    LOCAL_FIELD_NUMBER: builtins.int
    HELM_TARBALL_BLOB_ID_FIELD_NUMBER: builtins.int
    VALUES_OVERRIDES_FIELD_NUMBER: builtins.int
    RELEASE_NAME_FIELD_NUMBER: builtins.int
    NAMESPACE_FIELD_NUMBER: builtins.int
    @property
    def remote(self) -> global___RemoteHelmChart: ...
    @property
    def local(self) -> prodvana.proto.prodvana.common_config.kubernetes_config_pb2.LocalConfig: ...
    helm_tarball_blob_id: builtins.str
    @property
    def values_overrides(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___HelmValuesOverrides]: ...
    release_name: builtins.str
    """optional release name, leave blank to have Prodvana generate one.
    Mainly useful for migrating an existing helm release into Prodvana.
    """
    namespace: builtins.str
    """used internally by Prodvana, do not set."""
    def __init__(
        self,
        *,
        remote: global___RemoteHelmChart | None = ...,
        local: prodvana.proto.prodvana.common_config.kubernetes_config_pb2.LocalConfig | None = ...,
        helm_tarball_blob_id: builtins.str = ...,
        values_overrides: collections.abc.Iterable[global___HelmValuesOverrides] | None = ...,
        release_name: builtins.str = ...,
        namespace: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["chart_oneof", b"chart_oneof", "helm_tarball_blob_id", b"helm_tarball_blob_id", "local", b"local", "remote", b"remote"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["chart_oneof", b"chart_oneof", "helm_tarball_blob_id", b"helm_tarball_blob_id", "local", b"local", "namespace", b"namespace", "release_name", b"release_name", "remote", b"remote", "values_overrides", b"values_overrides"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["chart_oneof", b"chart_oneof"]) -> typing_extensions.Literal["remote", "local", "helm_tarball_blob_id"] | None: ...

global___HelmConfig = HelmConfig



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class K8SRuntimeInitializationConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class EnvVarsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    AGENT_IMAGE_FIELD_NUMBER: builtins.int
    AUTH_TOKEN_FIELD_NUMBER: builtins.int
    USE_RESOURCE_DEFAULT_FIELD_NUMBER: builtins.int
    INTERACTION_SERVER_ADDRESS_FIELD_NUMBER: builtins.int
    ENV_VARS_FIELD_NUMBER: builtins.int
    AGENT_EXTERNALLY_MANAGED_FIELD_NUMBER: builtins.int
    agent_image: builtins.str
    auth_token: builtins.str
    use_resource_default: builtins.bool
    interaction_server_address: builtins.str
    @property
    def env_vars(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Env vars, mainly used to pass in proxy information. This is generally supplied by customers."""
    agent_externally_managed: builtins.bool
    """The Prodvana agent lifecycle is handled by the user -- Prodvana will not install or update the agent."""
    def __init__(
        self,
        *,
        agent_image: builtins.str = ...,
        auth_token: builtins.str = ...,
        use_resource_default: builtins.bool = ...,
        interaction_server_address: builtins.str = ...,
        env_vars: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        agent_externally_managed: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["agent_externally_managed", b"agent_externally_managed", "agent_image", b"agent_image", "auth_token", b"auth_token", "env_vars", b"env_vars", "interaction_server_address", b"interaction_server_address", "use_resource_default", b"use_resource_default"]) -> None: ...

global___K8SRuntimeInitializationConfig = K8SRuntimeInitializationConfig

class RuntimeInitializationConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    K8S_FIELD_NUMBER: builtins.int
    @property
    def k8s(self) -> global___K8SRuntimeInitializationConfig: ...
    def __init__(
        self,
        *,
        k8s: global___K8SRuntimeInitializationConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["k8s", b"k8s", "runtime_specific", b"runtime_specific"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["k8s", b"k8s", "runtime_specific", b"runtime_specific"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["runtime_specific", b"runtime_specific"]) -> typing_extensions.Literal["k8s"] | None: ...

global___RuntimeInitializationConfig = RuntimeInitializationConfig

class ContainerOrchestrationRuntime(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class K8s(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        NAMESPACE_FIELD_NUMBER: builtins.int
        PVN_MANAGED_FIELD_NUMBER: builtins.int
        namespace: builtins.str
        """optionally set a custom namespace. If not set, Prodvana will create and manage the namespace.
        If set, the namespace *must* already exist and Prodvana will not try to create or delete it.
        """
        pvn_managed: builtins.bool
        """do not set this, this is used internally by Prodvana to keep track of if a namespace
        is managed by Prodvana or externally.
        """
        def __init__(
            self,
            *,
            namespace: builtins.str = ...,
            pvn_managed: builtins.bool = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["namespace", b"namespace", "pvn_managed", b"pvn_managed"]) -> None: ...

    class ECS(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        PREFIX_FIELD_NUMBER: builtins.int
        prefix: builtins.str
        def __init__(
            self,
            *,
            prefix: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["prefix", b"prefix"]) -> None: ...

    K8S_FIELD_NUMBER: builtins.int
    ECS_FIELD_NUMBER: builtins.int
    @property
    def k8s(self) -> global___ContainerOrchestrationRuntime.K8s: ...
    @property
    def ecs(self) -> global___ContainerOrchestrationRuntime.ECS: ...
    def __init__(
        self,
        *,
        k8s: global___ContainerOrchestrationRuntime.K8s | None = ...,
        ecs: global___ContainerOrchestrationRuntime.ECS | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["backend", b"backend", "ecs", b"ecs", "k8s", b"k8s"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["backend", b"backend", "ecs", b"ecs", "k8s", b"k8s"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["backend", b"backend"]) -> typing_extensions.Literal["k8s", "ecs"] | None: ...

global___ContainerOrchestrationRuntime = ContainerOrchestrationRuntime

class RuntimeExecutionConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RUNTIME_FIELD_NUMBER: builtins.int
    CONTAINER_ORCHESTRATION_FIELD_NUMBER: builtins.int
    runtime: builtins.str
    @property
    def container_orchestration(self) -> global___ContainerOrchestrationRuntime: ...
    def __init__(
        self,
        *,
        runtime: builtins.str = ...,
        container_orchestration: global___ContainerOrchestrationRuntime | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["container_orchestration", b"container_orchestration", "type_oneof", b"type_oneof"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["container_orchestration", b"container_orchestration", "runtime", b"runtime", "type_oneof", b"type_oneof"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["type_oneof", b"type_oneof"]) -> typing_extensions.Literal["container_orchestration"] | None: ...

global___RuntimeExecutionConfig = RuntimeExecutionConfig



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _Class:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ClassEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_Class.ValueType], builtins.type):  # noqa: F821
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    UNKNOWN: _Class.ValueType  # 0
    SUCCESSFUL_DEPLOYMENT_FREQUENCY_DECREASE: _Class.ValueType  # 1
    DEPLOYMENT_FAILURE_RATE_INCREASE: _Class.ValueType  # 2
    MEDIAN_SUCCESSFUL_DEPLOYMENT_DURATION_INCREASE: _Class.ValueType  # 3
    MEDIAN_SUCCESSFUL_ROLLBACK_DURATION_INCREASE: _Class.ValueType  # 4

class Class(_Class, metaclass=_ClassEnumTypeWrapper): ...

UNKNOWN: Class.ValueType  # 0
SUCCESSFUL_DEPLOYMENT_FREQUENCY_DECREASE: Class.ValueType  # 1
DEPLOYMENT_FAILURE_RATE_INCREASE: Class.ValueType  # 2
MEDIAN_SUCCESSFUL_DEPLOYMENT_DURATION_INCREASE: Class.ValueType  # 3
MEDIAN_SUCCESSFUL_ROLLBACK_DURATION_INCREASE: Class.ValueType  # 4
global___Class = Class

class Insight(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class Subject(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        ID_FIELD_NUMBER: builtins.int
        NAME_FIELD_NUMBER: builtins.int
        id: builtins.str
        name: builtins.str
        def __init__(
            self,
            *,
            id: builtins.str = ...,
            name: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["id", b"id", "name", b"name"]) -> None: ...

    TITLE_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    CLASS_FIELD_NUMBER: builtins.int
    SERVICE_FIELD_NUMBER: builtins.int
    APPLICATION_FIELD_NUMBER: builtins.int
    ORGANIZATION_FIELD_NUMBER: builtins.int
    title: builtins.str
    description: builtins.str
    @property
    def service(self) -> global___Insight.Subject: ...
    @property
    def application(self) -> global___Insight.Subject: ...
    @property
    def organization(self) -> global___Insight.Subject: ...
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        description: builtins.str = ...,
        service: global___Insight.Subject | None = ...,
        application: global___Insight.Subject | None = ...,
        organization: global___Insight.Subject | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["application", b"application", "organization", b"organization", "service", b"service", "subject_oneof", b"subject_oneof"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["application", b"application", "class", b"class", "description", b"description", "organization", b"organization", "service", b"service", "subject_oneof", b"subject_oneof", "title", b"title"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["subject_oneof", b"subject_oneof"]) -> typing_extensions.Literal["service", "application", "organization"] | None: ...

global___Insight = Insight



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from prodvana.proto.prodvana.managed_resource import manager_pb2 as prodvana_dot_managed__resource_dot_manager__pb2


class ResourceManagerStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ConfigureK8sCluster = channel.unary_unary(
                '/prodvana.managed_resource.ResourceManager/ConfigureK8sCluster',
                request_serializer=prodvana_dot_managed__resource_dot_manager__pb2.ConfigureK8sClusterReq.SerializeToString,
                response_deserializer=prodvana_dot_managed__resource_dot_manager__pb2.ConfigureK8sClusterResp.FromString,
                )
        self.GetManagedResource = channel.unary_unary(
                '/prodvana.managed_resource.ResourceManager/GetManagedResource',
                request_serializer=prodvana_dot_managed__resource_dot_manager__pb2.GetManagedResourceReq.SerializeToString,
                response_deserializer=prodvana_dot_managed__resource_dot_manager__pb2.GetManagedResourceResp.FromString,
                )
        self.ListManagedResources = channel.unary_unary(
                '/prodvana.managed_resource.ResourceManager/ListManagedResources',
                request_serializer=prodvana_dot_managed__resource_dot_manager__pb2.ListManagedResourcesReq.SerializeToString,
                response_deserializer=prodvana_dot_managed__resource_dot_manager__pb2.ListManagedResourcesResp.FromString,
                )
        self.GetArchive = channel.unary_stream(
                '/prodvana.managed_resource.ResourceManager/GetArchive',
                request_serializer=prodvana_dot_managed__resource_dot_manager__pb2.GetArchiveReq.SerializeToString,
                response_deserializer=prodvana_dot_managed__resource_dot_manager__pb2.GetArchiveResp.FromString,
                )
        self.DeleteManagedResource = channel.unary_unary(
                '/prodvana.managed_resource.ResourceManager/DeleteManagedResource',
                request_serializer=prodvana_dot_managed__resource_dot_manager__pb2.DeleteManagedResourceReq.SerializeToString,
                response_deserializer=prodvana_dot_managed__resource_dot_manager__pb2.DeleteManagedResourceResp.FromString,
                )
        self.MarkRunDone = channel.unary_unary(
                '/prodvana.managed_resource.ResourceManager/MarkRunDone',
                request_serializer=prodvana_dot_managed__resource_dot_manager__pb2.MarkRunDoneReq.SerializeToString,
                response_deserializer=prodvana_dot_managed__resource_dot_manager__pb2.MarkRunDoneResp.FromString,
                )


class ResourceManagerServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ConfigureK8sCluster(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetManagedResource(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListManagedResources(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetArchive(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteManagedResource(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def MarkRunDone(self, request, context):
        """TODO(naphat) delete this endpoint once we automate pulumi runs
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ResourceManagerServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ConfigureK8sCluster': grpc.unary_unary_rpc_method_handler(
                    servicer.ConfigureK8sCluster,
                    request_deserializer=prodvana_dot_managed__resource_dot_manager__pb2.ConfigureK8sClusterReq.FromString,
                    response_serializer=prodvana_dot_managed__resource_dot_manager__pb2.ConfigureK8sClusterResp.SerializeToString,
            ),
            'GetManagedResource': grpc.unary_unary_rpc_method_handler(
                    servicer.GetManagedResource,
                    request_deserializer=prodvana_dot_managed__resource_dot_manager__pb2.GetManagedResourceReq.FromString,
                    response_serializer=prodvana_dot_managed__resource_dot_manager__pb2.GetManagedResourceResp.SerializeToString,
            ),
            'ListManagedResources': grpc.unary_unary_rpc_method_handler(
                    servicer.ListManagedResources,
                    request_deserializer=prodvana_dot_managed__resource_dot_manager__pb2.ListManagedResourcesReq.FromString,
                    response_serializer=prodvana_dot_managed__resource_dot_manager__pb2.ListManagedResourcesResp.SerializeToString,
            ),
            'GetArchive': grpc.unary_stream_rpc_method_handler(
                    servicer.GetArchive,
                    request_deserializer=prodvana_dot_managed__resource_dot_manager__pb2.GetArchiveReq.FromString,
                    response_serializer=prodvana_dot_managed__resource_dot_manager__pb2.GetArchiveResp.SerializeToString,
            ),
            'DeleteManagedResource': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteManagedResource,
                    request_deserializer=prodvana_dot_managed__resource_dot_manager__pb2.DeleteManagedResourceReq.FromString,
                    response_serializer=prodvana_dot_managed__resource_dot_manager__pb2.DeleteManagedResourceResp.SerializeToString,
            ),
            'MarkRunDone': grpc.unary_unary_rpc_method_handler(
                    servicer.MarkRunDone,
                    request_deserializer=prodvana_dot_managed__resource_dot_manager__pb2.MarkRunDoneReq.FromString,
                    response_serializer=prodvana_dot_managed__resource_dot_manager__pb2.MarkRunDoneResp.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'prodvana.managed_resource.ResourceManager', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class ResourceManager(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ConfigureK8sCluster(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.managed_resource.ResourceManager/ConfigureK8sCluster',
            prodvana_dot_managed__resource_dot_manager__pb2.ConfigureK8sClusterReq.SerializeToString,
            prodvana_dot_managed__resource_dot_manager__pb2.ConfigureK8sClusterResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetManagedResource(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.managed_resource.ResourceManager/GetManagedResource',
            prodvana_dot_managed__resource_dot_manager__pb2.GetManagedResourceReq.SerializeToString,
            prodvana_dot_managed__resource_dot_manager__pb2.GetManagedResourceResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListManagedResources(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.managed_resource.ResourceManager/ListManagedResources',
            prodvana_dot_managed__resource_dot_manager__pb2.ListManagedResourcesReq.SerializeToString,
            prodvana_dot_managed__resource_dot_manager__pb2.ListManagedResourcesResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetArchive(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/prodvana.managed_resource.ResourceManager/GetArchive',
            prodvana_dot_managed__resource_dot_manager__pb2.GetArchiveReq.SerializeToString,
            prodvana_dot_managed__resource_dot_manager__pb2.GetArchiveResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteManagedResource(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.managed_resource.ResourceManager/DeleteManagedResource',
            prodvana_dot_managed__resource_dot_manager__pb2.DeleteManagedResourceReq.SerializeToString,
            prodvana_dot_managed__resource_dot_manager__pb2.DeleteManagedResourceResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def MarkRunDone(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.managed_resource.ResourceManager/MarkRunDone',
            prodvana_dot_managed__resource_dot_manager__pb2.MarkRunDoneReq.SerializeToString,
            prodvana_dot_managed__resource_dot_manager__pb2.MarkRunDoneResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/runtimes/features.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n prodvana/runtimes/features.proto\x12\x11prodvana.runtimes*s\n\x0b\x46\x65\x61tureType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x13\n\x0f\x45XPOSED_SERVICE\x10\x01\x12\x0f\n\x0bTLS_SERVICE\x10\x02\x12\x11\n\rCOST_ANALYSIS\x10\x03\x12\x0b\n\x07\x44\x41TADOG\x10\x04\x12\x11\n\rARGO_ROLLOUTS\x10\x05\x42MZKgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/runtimesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'prodvana.runtimes.features_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZKgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/runtimes'
  _globals['_FEATURETYPE']._serialized_start=55
  _globals['_FEATURETYPE']._serialized_end=170
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/runtimes/extensions/fetch.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from prodvana.proto.prodvana.common_config import external_link_pb2 as prodvana_dot_common__config_dot_external__link__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(prodvana/runtimes/extensions/fetch.proto\x12\x1cprodvana.runtimes.extensions\x1a*prodvana/common_config/external_link.proto\"\x90\x01\n\x15\x45xternalObjectVersion\x12\x0f\n\x07version\x18\x01 \x01(\t\x12\x10\n\x08replicas\x18\x02 \x01(\x05\x12\x1a\n\x12\x61vailable_replicas\x18\x05 \x01(\x05\x12\x17\n\x0ftarget_replicas\x18\x06 \x01(\x05\x12\x0e\n\x06\x61\x63tive\x18\x03 \x01(\x08\x12\x0f\n\x07\x64rifted\x18\x04 \x01(\x08\"\xaf\x02\n\x0e\x45xternalObject\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0bobject_type\x18\x02 \x01(\t\x12\x45\n\x08versions\x18\x03 \x03(\x0b\x32\x33.prodvana.runtimes.extensions.ExternalObjectVersion\x12\x43\n\x06status\x18\x04 \x01(\x0e\x32\x33.prodvana.runtimes.extensions.ExternalObject.Status\x12<\n\x0e\x65xternal_links\x18\x05 \x03(\x0b\x32$.prodvana.common_config.ExternalLink\"0\n\x06Status\x12\x0b\n\x07PENDING\x10\x00\x12\r\n\tSUCCEEDED\x10\x01\x12\n\n\x06\x46\x41ILED\x10\x02\"L\n\x0b\x46\x65tchOutput\x12=\n\x07objects\x18\x01 \x03(\x0b\x32,.prodvana.runtimes.extensions.ExternalObject*I\n\tFetchMode\x12\x16\n\x12UNKNOWN_FETCH_MODE\x10\x00\x12\r\n\tEXIT_CODE\x10\x01\x12\x15\n\x11STRUCTURED_OUTPUT\x10\x02\x42XZVgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/runtimes/extensionsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'prodvana.runtimes.extensions.fetch_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZVgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/runtimes/extensions'
  _globals['_FETCHMODE']._serialized_start=649
  _globals['_FETCHMODE']._serialized_end=722
  _globals['_EXTERNALOBJECTVERSION']._serialized_start=119
  _globals['_EXTERNALOBJECTVERSION']._serialized_end=263
  _globals['_EXTERNALOBJECT']._serialized_start=266
  _globals['_EXTERNALOBJECT']._serialized_end=569
  _globals['_EXTERNALOBJECT_STATUS']._serialized_start=521
  _globals['_EXTERNALOBJECT_STATUS']._serialized_end=569
  _globals['_FETCHOUTPUT']._serialized_start=571
  _globals['_FETCHOUTPUT']._serialized_end=647
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.duration_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import prodvana.proto.prodvana.common_config.parameters_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class ProtectionLifecycle(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class PreApproval(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        def __init__(
            self,
        ) -> None: ...

    class PostApproval(google.protobuf.message.Message):
        """message Approval {
        }
        """

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        def __init__(
            self,
        ) -> None: ...

    class Deployment(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        def __init__(
            self,
        ) -> None: ...

    class PostDeployment(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        DELAY_CHECK_DURATION_FIELD_NUMBER: builtins.int
        CHECK_DURATION_FIELD_NUMBER: builtins.int
        @property
        def delay_check_duration(self) -> google.protobuf.duration_pb2.Duration:
            """How long after the deployment completes should we start checking status?
            e.g, delay health checks X minutes after deployment (if deployment is noisy).
            """
        @property
        def check_duration(self) -> google.protobuf.duration_pb2.Duration:
            """How long after starting should we check for?"""
        def __init__(
            self,
            *,
            delay_check_duration: google.protobuf.duration_pb2.Duration | None = ...,
            check_duration: google.protobuf.duration_pb2.Duration | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["check_duration", b"check_duration", "delay_check_duration", b"delay_check_duration"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["check_duration", b"check_duration", "delay_check_duration", b"delay_check_duration"]) -> None: ...

    PRE_APPROVAL_FIELD_NUMBER: builtins.int
    POST_APPROVAL_FIELD_NUMBER: builtins.int
    DEPLOYMENT_FIELD_NUMBER: builtins.int
    POST_DEPLOYMENT_FIELD_NUMBER: builtins.int
    @property
    def pre_approval(self) -> global___ProtectionLifecycle.PreApproval:
        """NOTE: Type here must match CustomTaskType"""
    @property
    def post_approval(self) -> global___ProtectionLifecycle.PostApproval:
        """Approval approval = 2;"""
    @property
    def deployment(self) -> global___ProtectionLifecycle.Deployment: ...
    @property
    def post_deployment(self) -> global___ProtectionLifecycle.PostDeployment: ...
    def __init__(
        self,
        *,
        pre_approval: global___ProtectionLifecycle.PreApproval | None = ...,
        post_approval: global___ProtectionLifecycle.PostApproval | None = ...,
        deployment: global___ProtectionLifecycle.Deployment | None = ...,
        post_deployment: global___ProtectionLifecycle.PostDeployment | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["deployment", b"deployment", "lifecycle", b"lifecycle", "post_approval", b"post_approval", "post_deployment", b"post_deployment", "pre_approval", b"pre_approval"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["deployment", b"deployment", "lifecycle", b"lifecycle", "post_approval", b"post_approval", "post_deployment", b"post_deployment", "pre_approval", b"pre_approval"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["lifecycle", b"lifecycle"]) -> typing_extensions.Literal["pre_approval", "post_approval", "deployment", "post_deployment"] | None: ...

global___ProtectionLifecycle = ProtectionLifecycle

class ProtectionReference(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    PARAMETERS_FIELD_NUMBER: builtins.int
    name: builtins.str
    @property
    def parameters(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.common_config.parameters_pb2.ParameterValue]: ...
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        parameters: collections.abc.Iterable[prodvana.proto.prodvana.common_config.parameters_pb2.ParameterValue] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "parameters", b"parameters"]) -> None: ...

global___ProtectionReference = ProtectionReference



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/version/source_metadata.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&prodvana/version/source_metadata.proto\x12\x10prodvana.version\"V\n\x0eSourceMetadata\x12\x10\n\x08repo_url\x18\x01 \x01(\t\x12\x11\n\tfile_path\x18\x02 \x01(\t\x12\x0e\n\x06\x63ommit\x18\x03 \x01(\t\x12\x0f\n\x07user_id\x18\x04 \x01(\t*v\n\x06Source\x12\x12\n\x0eUNKNOWN_SOURCE\x10\x00\x12\x07\n\x03WEB\x10\x01\x12\x16\n\x12INTERACTIVE_PVNCTL\x10\x02\x12\x0f\n\x0b\x43ONFIG_FILE\x10\x03\x12\x0f\n\x0bREPO_FOLLOW\x10\x04\x12\x0c\n\x08PRODVANA\x10\x05\x12\x07\n\x03IAC\x10\x06\x42LZJgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/versionb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'prodvana.version.source_metadata_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZJgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/version'
  _globals['_SOURCE']._serialized_start=148
  _globals['_SOURCE']._serialized_end=266
  _globals['_SOURCEMETADATA']._serialized_start=60
  _globals['_SOURCEMETADATA']._serialized_end=146
# @@protoc_insertion_point(module_scope)
